/* Special definitions for shar, processed by autoheader.
   Copyright (C) 1994 Free Software Foundation, Inc.
   Francois Pinard <pinard@iro.umontreal.ca>, 1994.
*/

/* Define if the current hostname may be found in /etc/systemid.  */
#undef HAVE_ETC_SYSTEMID

/* Define to 1 if ANSI function prototypes are usable.  */
#undef PROTOTYPES

/* Define to 1 for better use of the debugging malloc library.  See 
   site ftp.antaire.com in antaire/src, file dmalloc/dmalloc.tar.gz.  */
#undef WITH_DMALLOC
